@@ -3,21 +3,29 @@ from collections import OrderedDict
 from typing import Optional, List
 
 from strictdoc.backend.sdoc.document_reference import DocumentReference
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.document_grammar import (
+    DocumentGrammar,
+    GrammarElement,
+)
 from strictdoc.backend.sdoc.models.node import Node
 from strictdoc.backend.sdoc.models.reference import Reference
 from strictdoc.backend.sdoc.models.type_system import (
     RequirementFieldName,
     RESERVED_NON_META_FIELDS,
 )
+from strictdoc.helpers.auto_described import auto_described
 
 MULTILINE_WORD_THRESHOLD = 6
 
 
+@auto_described
 class RequirementContext:
     def __init__(self):
         self.title_number_string = None
 
 
+@auto_described
 class RequirementField:
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -54,18 +62,11 @@ class RequirementField:
             List[Reference]
         ] = field_value_references
 
-    def __str__(self):
-        return (
-            f"{self.__class__.__name__}("
-            f"field_name: {self.field_name}, "
-            f"field_value: {self.field_value}, "
-            f"field_value_multiline: {self.field_value_multiline}, "
-            f"field_value_references: {self.field_value_references}, "
-            ")"
+    def get_value(self):
+        value = (
+            self.field_value if self.field_value else self.field_value_multiline
         )
-
-    def __repr__(self):
-        return self.__str__()
+        return value
 
 
 class Requirement(Node):  # pylint: disable=too-many-instance-attributes
@@ -188,7 +189,11 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         # TODO: Is it worth to move this to dedicated Presenter* classes to
         # keep this class textx-only?
         self.has_meta: bool = has_meta
-        self.fields: List[RequirementField] = fields
+
+        # This property is only used for validating fields against grammar
+        # during TextX parsing and processing.
+        self.fields_as_parsed = fields
+
         self.ordered_fields_lookup: OrderedDict[
             str, List[RequirementField]
         ] = ordered_fields_lookup
@@ -196,21 +201,7 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         self.ng_document_reference: Optional[DocumentReference] = None
         self.context = RequirementContext()
 
-        self.node_id = uuid.uuid4().hex
-
-    def __str__(self):
-        return (
-            f"{self.__class__.__name__}("
-            f"ng_level: {self.ng_level}, "
-            f"level: {self.level}, "
-            f"uid: {self.uid}, "
-            f"title_or_none: {self.title}, "
-            f"statement: {self.statement}"
-            ")"
-        )
-
-    def __repr__(self):
-        return self.__str__()
+        self.node_id: str = uuid.uuid4().hex
 
     @property
     def is_requirement(self):
@@ -274,7 +265,7 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
     def enumerate_meta_fields(
         self, skip_single_lines=False, skip_multi_lines=False
     ):
-        for field in self.fields:
+        for field in self.enumerate_fields():
             if field.field_name in RESERVED_NON_META_FIELDS:
                 continue
             meta_field_value = (
@@ -311,17 +302,118 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         meta_field_value = meta_field_value_or_none
         return meta_field_value
 
-    def dump_fields(self):
+    def dump_fields_as_parsed(self):
         return ", ".join(
             list(
                 map(
                     lambda r: r.field_name,
-                    self.fields,
+                    self.fields_as_parsed,
                 )
             )
         )
 
+    # Below all mutating methods.
 
+    def set_field_value(self, field_name: str, value):
+        """
+        The purpose of this purpose is to provide a single-method API for
+        updating any field of a requirement. A requirement might use only some
+        fields of a document grammar, so an extra exercise done by the method is
+        to ensure that an added field that has not been attached to the
+        requirement before will be put at the right index.
+        """
+        assert isinstance(field_name, str)
+
+        # If a field value is being removed, there is not much to do.
+        if value is None or len(value) == 0:
+            if field_name in self.ordered_fields_lookup:
+                del self.ordered_fields_lookup[field_name]
+            return
+
+        singleline_fields = {"UID", "TITLE"}
+        multiline_fields = {"STATEMENT", "RATIONALE"}
+
+        field_value = None
+        field_value_multiline = None
+        field_value_references = None
+        if field_name in singleline_fields:
+            field_value = value
+        elif field_name in multiline_fields:
+            field_value_multiline = value
+        else:
+            raise NotImplementedError(value)
+
+        # FIXME: This will go away.
+        if field_name == RequirementFieldName.UID:
+            self.uid = field_value
+        elif field_name == RequirementFieldName.TITLE:
+            self.title = field_value
+        elif field_name == RequirementFieldName.TAGS:
+            self.tags = field_value
+        elif field_name == RequirementFieldName.LEVEL:
+            self.level = field_value
+        elif field_name == RequirementFieldName.STATUS:
+            self.status = field_value
+        elif field_name == RequirementFieldName.STATEMENT:
+            self.statement_multiline = field_value_multiline
+            self.statement = None
+        elif field_name == RequirementFieldName.RATIONALE:
+            self.rationale_multiline = field_value_multiline
+            self.rationale = None
+
+        if field_name in self.ordered_fields_lookup:
+            self.ordered_fields_lookup[field_name] = [
+                RequirementField(
+                    self,
+                    field_name=field_name,
+                    field_value=field_value,
+                    field_value_multiline=field_value_multiline,
+                    field_value_references=field_value_references,
+                )
+            ]
+            return
+
+        new_ordered_fields_lookup = OrderedDict()
+        document: Document = self.document
+        grammar_or_none: Optional[DocumentGrammar] = document.grammar
+        assert grammar_or_none is not None
+        grammar: DocumentGrammar = grammar_or_none
+
+        element: GrammarElement = grammar.elements_by_type["REQUIREMENT"]
+        grammar_field_titles = list(map(lambda f: f.title, element.fields))
+        field_index = grammar_field_titles.index(field_name)
+        for field_title in grammar_field_titles[:field_index]:
+            if field_title in self.ordered_fields_lookup:
+                new_ordered_fields_lookup[
+                    field_title
+                ] = self.ordered_fields_lookup[field_title]
+        new_ordered_fields_lookup[field_name] = [
+            RequirementField(
+                self,
+                field_name=field_name,
+                field_value=field_value,
+                field_value_multiline=field_value_multiline,
+                field_value_references=field_value_references,
+            )
+        ]
+        after_field_index = field_index + 1
+        for field_title in grammar_field_titles[after_field_index:]:
+            if field_title in self.ordered_fields_lookup:
+                new_ordered_fields_lookup[
+                    field_title
+                ] = self.ordered_fields_lookup[field_title]
+        self.ordered_fields_lookup = new_ordered_fields_lookup
+        self._update_has_meta()
+
+    def _update_has_meta(self):
+        has_meta: bool = False
+        for field in self.enumerate_fields():
+            if field.field_name not in RESERVED_NON_META_FIELDS:
+                has_meta = True
+        self.has_meta = has_meta
+
+
+@auto_described
 class CompositeRequirement(Requirement):
     def __init__(self, parent, **fields):
         super().__init__(parent, **fields)
@@ -337,18 +429,14 @@ class CompositeRequirement(Requirement):
         return self.ng_document_reference.get_document()
 
 
+@auto_described
 class Body:
     def __init__(self, parent, content):
         self.parent = parent
         self.content = content.strip()
 
-    def __str__(self):
-        return f"Body({self.content})"
-
-    def __repr__(self):
-        return self.__str__()
-
 
+@auto_described
 class RequirementComment:
     def __init__(
         self,
@@ -368,17 +456,6 @@ class RequirementComment:
         # TODO: One solution to simplify this would be to disallow empty fields
         # in the grammar completely.
 
-    def __str__(self):
-        return (
-            f"Comment("
-            f"comment_single: {self.comment_single}, "
-            f"comment_multiline: {self.comment_multiline}"
-            f")"
-        )
-
-    def __repr__(self):
-        return self.__str__()
-
     def get_comment(self):
         comment = (
             self.comment_single
