@@ -1,7 +1,7 @@
 // This code in this file is a simplified version of the StackOverflow answer
 // taken from: https://stackoverflow.com/a/33948409/598057.
 
-$(document).ready(function() {
+$(document).ready(function () {
   var state = {
     spacePressed: false,
     isDown: false,
@@ -9,38 +9,42 @@ $(document).ready(function() {
     startY: 0
   }
 
-  var element = '.layout_main';
+  const element = $('#pan-with-space');
 
   $(window).keydown(function (e) {
     if (e.key === ' ' || e.key === 'Spacebar') {
       // ' ' is standard, 'Spacebar' was used by IE9 and Firefox < 37
 
+      e.preventDefault();
+      e.stopPropagation();
       state.spacePressed = true;
-      $(element).css('cursor', 'move');
+      element.css('cursor', 'move');
     }
+
     var moveFactor = 20;
-    if (event.altKey) {
+    if (e.altKey) {
       moveFactor = 250;
     }
+
     if (e.key === 'ArrowDown') {
       e.preventDefault();
       e.stopPropagation();
-      $(element).scrollTop($(element).scrollTop() + moveFactor);
+      element.scrollTop(element.scrollTop() + moveFactor);
     }
     else if (e.key === 'ArrowUp') {
       e.preventDefault();
       e.stopPropagation();
-      $(element).scrollTop($(element).scrollTop() - moveFactor);
+      element.scrollTop(element.scrollTop() - moveFactor);
     }
     else if (e.key === 'ArrowLeft') {
       e.preventDefault();
       e.stopPropagation();
-      $(element).scrollLeft($(element).scrollLeft() - moveFactor);
+      element.scrollLeft(element.scrollLeft() - moveFactor);
     }
     else if (e.key === 'ArrowRight') {
       e.preventDefault();
       e.stopPropagation();
-      $(element).scrollLeft($(element).scrollLeft() + moveFactor);
+      element.scrollLeft(element.scrollLeft() + moveFactor);
     }
   })
 
@@ -50,11 +54,11 @@ $(document).ready(function() {
       e.preventDefault();
       e.stopPropagation();
       state.spacePressed = false;
-      $(element).css('cursor', 'default');
+      element.css('cursor', 'default');
     }
   })
 
-  $(element).mousedown(function (e) {
+  element.mousedown(function (e) {
     if (!state.spacePressed) {
       return;
     }
@@ -73,7 +77,7 @@ $(document).ready(function() {
     state.isDown = true;
   });
 
-  $(element).mouseup(function (e) {
+  element.mouseup(function (e) {
     if (!state.spacePressed) {
       return;
     }
@@ -84,8 +88,8 @@ $(document).ready(function() {
     state.isDown = false;
   });
 
-  $(element).mousemove(function (e) {
-    if (!state.isDown){
+  element.mousemove(function (e) {
+    if (!state.isDown) {
       return;
     }
 
@@ -106,15 +110,15 @@ $(document).ready(function() {
     state.startY = mouseY;
 
     var speedupFactor = 2;
-    $(element).scrollTop($(element).scrollTop() - dy * speedupFactor);
-    $(element).scrollLeft($(element).scrollLeft() - dx * speedupFactor);
+    element.scrollTop(element.scrollTop() - dy * speedupFactor);
+    element.scrollLeft(element.scrollLeft() - dx * speedupFactor);
   });
 
-  $(element).mouseleave(function (e) {
+  element.mouseleave(function (e) {
     // tell the browser we're handling this event
     e.preventDefault();
     e.stopPropagation();
 
-    state.isDown=false;
+    state.isDown = false;
   });
 });
